;code by lucia and giangiacomo

globals [average-mice average-trees seed-quantity total-seeds  max-mice min-mice max-trees min-trees repr-energy remaining-seeds 
  colonization-index min-colonization-index max-colonization-index average-colonization-index]

breed [mice mouse]
breed [trees tree]

mice-own [energy age]
trees-own [age]
patches-own [seeds tree?]


to setup
  __clear-all-and-reset-ticks
                                        
  set average-mice 0
  set average-trees 0
  set-default-shape trees "circle"
  create-mice init-mice [set energy 0 setxy random-xcor random-ycor set color red set age 0] ;create init-mice of mice, in randomly choosen patches
  ask patches [set tree? false]
  ask n-of init-trees patches [  ;create init-trees of trees, each of them in a patch, choosen in a random way
    set tree? true
    sprout-trees 1 [set color green set age random 300]
  ]  
  set repr-energy (12 * (max-eaten - met-energy)) / max-offspring 
  
  seed-production 
  do-plots
end


to go
  tick
  
  set total-seeds 0
  set remaining-seeds sum [seeds] of patches
  
  let t (ticks mod 12)
  
  ifelse t >= 1 and t <= 6 [   ;from October to March: mice eat seeds
    ask mice [ eat-and-die? ]
  ][ask mice [eat-and-die2?]]  ;from April to September: mice eat something else 
  
  if t = 6 [   ;March: trees can die and new trees can grow up
    tree-dynamics
  ]
  
  if t = 0 [  ;September: trees produce seeds
    seed-production
  ]
  
  if t = 1 or t = 8 [ ;May and October: mice reproduce
    mice-reproduce
  ]
  
  if ticks > 1000 [
    ifelse ticks = 1001
    [
      set max-mice count mice
      set min-mice max-mice
      set max-trees count trees
      set min-trees max-trees
      set max-colonization-index colonization-index
      set min-colonization-index colonization-index
    ]
    [
      let n-mice count mice
      ifelse n-mice > max-mice [set max-mice n-mice] [if n-mice < min-mice [set min-mice n-mice]] 
      let n-trees count trees
      ifelse n-trees > max-trees [set max-trees n-trees] [if n-trees < min-trees [set min-trees n-trees]]
      ifelse colonization-index > max-colonization-index [set max-colonization-index colonization-index][if colonization-index < min-colonization-index [set min-colonization-index colonization-index]] 
    ]
    set average-mice (count mice + (ticks - 1001) * average-mice) / (ticks - 1000)
    set average-trees (count trees + (ticks - 1001) * average-trees) / (ticks - 1000)
    set average-colonization-index (colonization-index + (ticks - 1001)* average-colonization-index)/(ticks - 1000)
  ]
  do-plots
  if ticks > 2000 [stop]
end

;;;;;;;;   mouse procedures    ;;;;;;;;;

to eat-and-die?
  set age age + 1
  if (age > 36) or (random-float 1 < predator) [die]
  
  let movement 0 let eaten 0
  while[movement < max-movement and eaten < max-eaten] ;mice can make a number of movement every month to look for seeds
  [
    uphill seeds        ;mice go where the largest quantity of seeds 
    set movement movement + 1
    
    if seeds > 0 [        ;mouse eats, at most max-eaten
      let eaten-here min (list seeds (max-eaten - eaten)) 
      set eaten eaten + eaten-here
      ask patch-here [ set seeds seeds - eaten-here ]
    ]
  ]
  
  set energy energy + eaten - met-energy   ;mice have a metabolic cost and eventually die
  if energy <= 0 [die]
end


to eat-and-die2?
  set age age + 1
  if (age > 36) or (random-float 1 < predator) [die]
  
  let rnd random max-eaten
  set energy energy + rnd - met-energy   ;mice have a metabolic cost and eventually die
  if energy <= 0 [die]
end


to mice-reproduce
  ask mice  [  
    let offspring random( energy / repr-energy)
    hatch offspring [set energy 0 set age 0]
    set energy energy -  offspring * repr-energy
  ]
end


;;;;;;;;;;;;;;  tree procedures   ;;;;;;;;;;;;

to tree-dynamics
  ask trees [  ;trees eventually die
    if random-float 1 < death-prob [    
      ask patch-here [set tree? false]
      die
    ]
  ]
  
  let free-patches count(patches with [tree? = false])
  let germinator 0
  ask patches with [seeds > 0 ] [ ;new trees can grow up
    while [tree? = false and seeds > 0] [     
        ifelse random-float 1 < birth-prob [ 
          set germinator germinator + 1
          sprout-trees 1 [set color green set age 0]
          set tree? true
          set seeds 1
        ]
        [set seeds seeds - 1 ]
    ]
    set seeds 0  ;seeds die   
  ]
  ifelse free-patches = 0 [set colonization-index 1][set colonization-index ( germinator / free-patches )]
end  

to seed-production
  ifelse mast? = false  ;mast is a flag defined in interface
    [
      set seed-quantity average-seed      ;seed-quantity is the quantity of seeds produced in the current year by a tree
    ]
    [
      set seed-quantity ((mast-frequence / 12)* average-seed) / ((mast-frequence / 12) - 1 + mast-seed-proportion)
      if (ticks mod mast-frequence = 0) [set seed-quantity seed-quantity * mast-seed-proportion]
    ]  
    
  ask trees [set age age + 1]  
  ask trees with [age > 25]     ; trees produce seed and spread them in the neighbour patches
  [        
    let add-seeds max(list 0 (random-normal seed-quantity (seed-quantity / 4)))
    ask neighbors [ set seeds seeds + add-seeds / 8 ]
  ]    
  
  set total-seeds sum [seeds] of patches
end

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

to do-plots
  set-current-plot "N. of agents"
  set-current-plot-pen "Mice"
  plot count mice
  set-current-plot-pen "Trees"
  plot count trees  
end

to mice-age
  file-open "miceAge.txt"
  file-print "age"
  ask mice [file-print age]  
  file-close
end
@#$#@#$#@
GRAPHICS-WINDOW
786
7
1326
568
-1
-1
13.25
1
10
1
1
1
0
1
1
1
0
39
0
39
1
1
1
ticks
30.0

BUTTON
15
19
91
53
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
123
20
187
54
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
22
83
194
116
init-mice
init-mice
0
1000
500
100
1
NIL
HORIZONTAL

SLIDER
457
160
629
193
average-seed
average-seed
100
2200
650
50
1
NIL
HORIZONTAL

SLIDER
457
206
692
239
mast-seed-proportion
mast-seed-proportion
0
100
40
5
1
NIL
HORIZONTAL

SLIDER
23
131
195
164
met-energy
met-energy
5
20
8
1
1
NIL
HORIZONTAL

SWITCH
225
23
343
56
mast?
mast?
1
1
-1000

PLOT
17
232
429
470
N. of agents
Months
NIL
0.0
10.0
0.0
500.0
true
true
"" ""
PENS
"Mice" 1.0 0 -2674135 true "" ""
"Trees" 1.0 0 -10899396 true "" ""

SLIDER
465
255
650
288
mast-frequence
mast-frequence
36
168
60
12
1
NIL
HORIZONTAL

MONITOR
454
396
586
461
NIL
average-mice
0
1
16

SLIDER
446
16
618
49
init-trees
init-trees
0
1600
1600
50
1
NIL
HORIZONTAL

SLIDER
447
64
619
97
birth-prob
birth-prob
0
1
0.9
.001
1
NIL
HORIZONTAL

SLIDER
447
117
619
150
death-prob
death-prob
0
.1
0.035
.005
1
NIL
HORIZONTAL

MONITOR
454
311
576
376
NIL
average-trees
0
1
16

SLIDER
228
130
416
163
max-movement
max-movement
1
20
10
1
1
NIL
HORIZONTAL

MONITOR
586
312
674
377
NIL
min-trees
0
1
16

MONITOR
686
312
778
377
NIL
max-trees
0
1
16

MONITOR
596
396
688
461
NIL
max-mice
0
1
16

MONITOR
701
396
789
461
NIL
min-mice
0
1
16

SLIDER
26
176
198
209
predator
predator
0
1
0
0.005
1
NIL
HORIZONTAL

SLIDER
245
175
417
208
max-eaten
max-eaten
10
60
20
1
1
NIL
HORIZONTAL

SLIDER
228
80
400
113
max-offspring
max-offspring
6
10
9
1
1
NIL
HORIZONTAL

MONITOR
470
480
702
545
NIL
average-colonization-index
3
1
16

MONITOR
40
560
237
625
NIL
min-colonization-index
3
1
16

MONITOR
280
555
482
620
NIL
max-colonization-index
3
1
16

@#$#@#$#@
# THE MAST SEEDING MODEL

## AUTHORS

- Lucia Tamburino, Department of Landscape, Environment, Agriculture and Forestry (LEAF), University of Padova
- Giangiacomo Bravo, Department of Economics and Statistics, University of Torino, and Collegio Carlo Alberto

## MODEL OVERVIEW

The model represents a forest where trees, seeds and seed predators (i.e. mice) interact each other. 

A flag (the variable `mast` defined in the interface) allows the switching from a uniform seed production to a large synchronized seed production at large time intervals: the so called "mast seeding" phenomenon, largely observed in nature.
The model goal is to compare the forest dynamics under the two conditions.

A complete description of the model following the ODD protocol is enclosed as separate file.


## HOW IT WORKS

Trees produce seeds, mice eat seeds looking for them across the patches. New trees grow up from uneaten seeds. Mice reproduce depending on the energy they gain from food.


## HOW TO USE IT

1. In the interface, set the variable `mast` to "on" or "off". When "on", trees are able to do mast seeding; when "off", the seed production is uniform over the years. 
2. Eventually change the other variables (see the ODD description for their meaning).
3. Click on `setup`.
4. Click on `go`.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="1-Mouse-Tree-Parameters" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <steppedValueSet variable="average-seed" first="500" step="50" last="800"/>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.03"/>
      <value value="0.035"/>
      <value value="0.04"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <steppedValueSet variable="max-movement" first="8" step="1" last="12"/>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2-Masting-Parameters" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <steppedValueSet variable="mast-seed-proportion" first="10" step="10" last="70"/>
    <enumeratedValueSet variable="mast?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <steppedValueSet variable="mast-frequence" first="24" step="12" last="96"/>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="3-Predation" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <steppedValueSet variable="predator" first="0" step="0.02" last="0.12"/>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="4-s-max" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="max-eaten" first="15" step="5" last="50"/>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="prova1" repetitions="8" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="prova2" repetitions="8" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Single-Run" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <metric>count mice</metric>
    <metric>count trees</metric>
    <metric>total-seeds</metric>
    <metric>remaining-seeds</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="tommaso" repetitions="1" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <metric>count mice</metric>
    <metric>count trees</metric>
    <metric>total-seeds</metric>
    <metric>remaining-seeds</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="2-Masting-Parameters2" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="50"/>
      <value value="60"/>
      <value value="70"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <steppedValueSet variable="mast-frequence" first="24" step="12" last="96"/>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="Check" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>average-trees</metric>
    <metric>average-mice</metric>
    <metric>average-colonization-index</metric>
    <metric>min-trees</metric>
    <metric>min-mice</metric>
    <metric>min-colonization-index</metric>
    <metric>max-trees</metric>
    <metric>max-mice</metric>
    <metric>max-colonization-index</metric>
    <enumeratedValueSet variable="birth-prob">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-offspring">
      <value value="9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="predator">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-eaten">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="average-seed">
      <value value="650"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-seed-proportion">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast?">
      <value value="false"/>
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="met-energy">
      <value value="8"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-trees">
      <value value="1600"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="death-prob">
      <value value="0.035"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mast-frequence">
      <value value="60"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="max-movement">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-mice">
      <value value="500"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
1
@#$#@#$#@
